@@ -28,7 +28,8 @@ class S3FileInput(ClearableFileInput):
         element_id = final_attrs.get('id')
 
         if value:
-            file_url = default_storage.url(value)
+
+            file_url = value.url()
         else:
             file_url = ''
 
